@@ -27,7 +27,7 @@ class unsplit:
         tokens = re.split(" |(?<!-)\n", self.text)
         tokens = [l.strip() for l in tokens] 
         
-        # pick up anything with a -\n string in it
+        # pick up anything with a -\n string in it (except items with trailing "words" that are all numbers - these are end of page hyphens)
         regex = re.compile(".+[^-](-\n).+")
         has_newline = [x for x in tokens if regex.match(x)]
         
@@ -50,6 +50,8 @@ class unsplit:
         remove_hyphen = text.replace("-\n", "") + "\n"
         keep_hyphen = text.replace("-\n", "-") + "\n"
         unsure_hyphen = text.replace("-\n", "-*") + "\n"
+        end_pg_hyphen = text.replace("-\n", "-*\n") + " "
+
         
         
         # Define tests of "wordiness"
@@ -59,6 +61,7 @@ class unsplit:
         W2_real = W2 in word_set
         Has_proper = all([W1.istitle() == False, W2.istitle() == True])
         Has_num = any(filter(str.isdigit, W1) or filter(str.isdigit, W2))
+        End_pg = "--File" in W2 or W2.isdigit() == True
 
         # Decides whether a split word should retain its hyphen
         # To accomplish this, OCRfixr checks the hyphenated word against the accepted word list:
@@ -69,33 +72,42 @@ class unsplit:
         # - If word is NOT recognized without the hyphen, and both word halves are NOT recognized, REMOVE THE HYPHEN. These are assumed to be proper nouns.(ex: McAl-ister --> McAlister)
         #   - However, if the unrecognizable word is actually a number, then keep the hyphen (ex: 55-\n56 --> 55-56\n)
         #     OR, if the second word half is uppercased (likely a proper noun), then KEEP THE HYPHEN (ex. proto-Corinthian --> proto-Corinthian)
+        # - Lastly, if the hyphenated word is at the end of the page (the word is split across pages), then KEEP THE HYPHEN and indicate with a *. This overrides all other previous rules
+            # TODO: Also add a leading * to the first word on the following page
+            # -*\n+[0-9]?-+File:\s[0-9]+.png-+\n[A-z]+ ----> replace .png-+\n with .png-+\n*
 
-        if W0_real == True:
-            if W0_common == True:
-                return(remove_hyphen)
-            elif all([W1_real, W2_real]):
-                return(unsure_hyphen)
-            else:
-                return(remove_hyphen)
-               
-        else:    
-            if all([W1_real, W2_real]) or Has_num == True or Has_proper == True: 
-                return(keep_hyphen)
-            else:
-                return(remove_hyphen)
+        if End_pg == True:
+            return(end_pg_hyphen)
+        else:
+            if W0_real == True:
+                if W0_common == True:
+                    return(remove_hyphen)
+                elif all([W1_real, W2_real]):
+                    return(unsure_hyphen)
+                else:
+                    return(remove_hyphen)
+                   
+            else:    
+                if all([W1_real, W2_real]) or Has_num == True or Has_proper == True: 
+                    return(keep_hyphen)
+                else:
+                    return(remove_hyphen)
 
     
     # note that multi-replace will replace ALL instances of a split word. Hyphenation is NOT context-specific, it is rule-based
     def _MULTI_REPLACE(self, fixes):
-        # if there are no fixes, just return the original text
+        #if there are no fixes, just return the original text
         if len(fixes) == 0 :
             return(self.text)
         else:
         # otherwise, replace all split words with the approved replacement word from the dict, 
-        # TODO: removing optional trailing whitespace/newline after split word
-            fixes = dict((re.escape(k), v) for k, v in fixes.items()) 
-            pattern = re.compile("|".join(fixes.keys()))
-            text_corrected = pattern.sub(lambda m: fixes[re.escape(m.group(0))], self.text)
+            #fixes = dict((re.escape(k), v) for k, v in fixes.items()) 
+            #pattern = re.compile("|".join(fixes.keys()))
+            #text_corrected = pattern.sub(lambda m: fixes[re.escape(m.group(0))], self.text)
+            #return(text_corrected)
+            text_corrected = self.text
+            for i, j in fixes.items():
+                text_corrected = re.sub(re.escape(i) + "(\s|\n)?", j, text_corrected)
             return(text_corrected)
     
      
@@ -133,4 +145,3 @@ class unsplit:
                 full_results = correction
             return(full_results)
 
-
